@@ -70,6 +70,7 @@ my (@normal_virtuals) = qw(
   Perl-OSType
   Pod-Escapes
   Pod-Parser
+  Pod-Perldoc
   Pod-Simple
   Safe
   Scalar-List-Utils
@@ -139,7 +140,6 @@ BioPerl,sci-biology/bioperl
 BioPerl-DB,sci-biology/bioperl-db
 BioPerl-Network,sci-biology/bioperl-network
 BioPerl-Run,sci-biology/bioperl-run
-Cache-Mmap,dev-perl/cache-mmap
 DBIx-SearchBuilder,dev-perl/dbix-searchbuilder
 Data-Buffer,dev-perl/data-buffer
 Digest-BubbleBabble,dev-perl/digest-bubblebabble
